<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+14"/>
        <source>About Transmission</source>
        <translation>O Transmissionu</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Copyright © The Transmission Project</source>
        <translation>Avtorske pravice © The Transmission Project</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>Hiter in preprost BitTorrent odjemalec</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cc" line="+37"/>
        <source>Client</source>
        <translation>Odjemalec</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Server</source>
        <translation>Strežnik</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>C&amp;redits</source>
        <translation>Zasluge</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;License</source>
        <translation>&amp;Licenca</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Credits</source>
        <translation>Zasluge</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../Application.cc" line="+332"/>
        <source>&lt;b&gt;Transmission is a file sharing program.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Transmission je program za deljenje datotek&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>When you run a torrent, its data will be made available to others by means of upload. Any content you share is your sole responsibility.</source>
        <translation>Ko zaženete torrent, bodo njegovi podatki na voljo drugim preko nalaganja. Vsaka vsebina, ki jo delite, je vaša odgovornost.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>I &amp;Agree</source>
        <translation>Strinjam se</translation>
    </message>
    <message numerus="yes">
        <location line="+110"/>
        <source>Torrent(s) Completed</source>
        <translation>
            <numerusform>Torrent dokončan</numerusform>
            <numerusform>Torrenta dokončana</numerusform>
            <numerusform>Torrenti dokončani</numerusform>
            <numerusform>Torrenti dokončani</numerusform>
        </translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Torrent Added</source>
        <translation>Torrent dodan</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../DetailsDialog.cc" line="+432"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Mešano</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+267"/>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <location line="-210"/>
        <source>Finished</source>
        <translation>Dokončano</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>V premoru</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>%1 (+%2 discarded after failed checksum)</source>
        <translation>%1 (+%2 zavrženih po spodleteli nadzorni vsoti)</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Active now</source>
        <translation>Trenutno aktivno</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 ago</source>
        <translation>pred %1</translation>
    </message>
    <message numerus="yes">
        <location line="+63"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%Ln kos @ %2)</numerusform>
            <numerusform>%1 (%Ln kosa @ %2)</numerusform>
            <numerusform>%1 (%Ln kosi @ %2)</numerusform>
            <numerusform>%1 (%Ln kosov @ %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%Ln kos)</numerusform>
            <numerusform>%1 (%Ln kosa)</numerusform>
            <numerusform>%1 (%Ln kosi)</numerusform>
            <numerusform>%1 (%Ln kosov)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Vidno le temu sledilniku - DHT in PEX onemogočena</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Public torrent</source>
        <translation>Javni torrent</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Created by %1</source>
        <translation>Ustvaril %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created on %1</source>
        <translation>Ustvarjeno %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created by %1 on %2</source>
        <translation>Ustvaril %1 %2</translation>
    </message>
    <message>
        <location line="+204"/>
        <location line="+47"/>
        <source>Encrypted connection</source>
        <translation>Šifrirana povezava</translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Optimistic unchoke</source>
        <translation>Optimistično zadrževanje</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading from this peer</source>
        <translation>Prejemam od tega soležnika</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Bi prejemal od tega soležnika, če bi nam dovolil</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Uploading to peer</source>
        <translation>Pošiljanje soležniku</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Bi pošiljal temu soležniku, če bi rekel</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>Soležnik nas je nehal zadrževati, ampak nas ne zanima</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Soležnika smo nehali zadrževati, ampak jih to ne zanima</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer was discovered through DHT</source>
        <translation>Soležnik, najden preko DHT</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>Soležnik, najden preko PEX</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is an incoming connection</source>
        <translation>Soležnik je dohodna povezava</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is connected over µTP</source>
        <translation>Soležnik je povezan prek µTP</translation>
    </message>
    <message numerus="yes">
        <location line="+130"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>minuta</numerusform>
            <numerusform>minuti</numerusform>
            <numerusform>minute</numerusform>
            <numerusform>minut</numerusform>
        </translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Add tracker announce URLs, one per line:</source>
        <translation>Dodaj URL-je za objave sledilnika, vsakega v svojo vrstico:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No new URLs found.</source>
        <translation>Ni najdenih novih URL-jev.</translation>
    </message>
    <message>
        <location line="-843"/>
        <source>%1 (100%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data</extracomment>
        <translation>%1 (100%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data, %2 is overall size of torrent data, %3 is percentage (%1/%2*100)</extracomment>
        <translation>%1 od %2 (%3%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded data (both verified and unverified), %2 is overall size of torrent data, %3 is percentage (%1/%2*100), %4 is amount of downloaded but not yet verified data</extracomment>
        <translation>%1 od %2 (%3%), %4 Nepreverjeno</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>%1 (Ratio: %2)</source>
        <translation>%1 (Razmerje: %2)</translation>
    </message>
    <message>
        <location line="+273"/>
        <location line="+55"/>
        <source>N/A</source>
        <translation>Ni na voljo</translation>
    </message>
    <message>
        <location line="+390"/>
        <source>Add URL(s)</source>
        <translation>Dodaj URL-je</translation>
    </message>
    <message>
        <location line="+112"/>
        <source>High</source>
        <translation>Visoko</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normalno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Nizko</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+4"/>
        <source>Use Global Settings</source>
        <translation>Uporabi glavne nastavitve</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Seed regardless of ratio</source>
        <translation>Sej ne glede na razmerje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Prenehaj sejati pri razmerju:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Seed regardless of activity</source>
        <translation>Sej ne glede na aktivnost</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for:</source>
        <translation>Prenehaj sejati pri neaktivnosti za:</translation>
    </message>
    <message>
        <location line="+75"/>
        <source>Up</source>
        <translation>Gor</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Dol</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Stanje</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Odjemalec</translation>
    </message>
    <message>
        <location filename="../DetailsDialog.ui" line="+14"/>
        <source>Torrent Properties</source>
        <translation>Lastnosti torrenta</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Activity</source>
        <translation>Aktivnost</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Have:</source>
        <translation>Ima:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Availability:</source>
        <translation>Na voljo:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Uploaded:</source>
        <translation>Poslano:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Downloaded:</source>
        <translation>Prejeto:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>State:</source>
        <translation>Stanje:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Running time:</source>
        <translation>Čas delovanja:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Remaining time:</source>
        <translation>Preostali čas:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Last activity:</source>
        <translation>Zadnja aktivnost:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Error:</source>
        <translation>Napaka:</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Location:</source>
        <translation>Mesto:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Edit Trackers</source>
        <translation>Uredi sledilnike</translation>
    </message>
    <message>
        <location line="-190"/>
        <source>Hash:</source>
        <translation>Razpršilo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Privacy:</source>
        <translation>Zasebnost:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Origin:</source>
        <translation>Izvor:</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Added:</source>
        <translation>Dodan:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Comment:</source>
        <translation>Komentar:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Peers</source>
        <translation>Soležniki</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tracker</source>
        <translation>Sledilnik</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add Tracker</source>
        <translation>Dodaj sledilnik</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Remove Trackers</source>
        <translation>Odstrani sledilnike</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Show &amp;more details</source>
        <translation>Pokaži več podrobnosti</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show &amp;backup trackers</source>
        <translation>Pokaži pomožne sledilnike</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Files</source>
        <translation>Datoteke</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Speed</source>
        <translation>Hitrost</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Honor global &amp;limits</source>
        <translation>Upoštevaj splošne omejitve</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Limit &amp;download speed:</source>
        <translation>Omejitev hitrosti prenašanja:</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Limit &amp;upload speed:</source>
        <translation>Omejitev hitrosti pošiljanja:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Torrent &amp;priority:</source>
        <translation>Prioriteta torrenta:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Seeding Limits</source>
        <translation>Omejitve sejanja:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Ratio:</source>
        <translation>Razmerje</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Idle:</source>
        <translation>Neaktivno:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Peer Connections</source>
        <translation>Povezave do soležnikov</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Maximum peers:</source>
        <translation>Največ soležnikov:</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../FileTreeItem.cc" line="+297"/>
        <location filename="../FileTreeView.cc" line="+108"/>
        <location line="+254"/>
        <source>Low</source>
        <translation>Nizko</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-254"/>
        <location line="+252"/>
        <source>High</source>
        <translation>Visoko</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <location line="+253"/>
        <source>Normal</source>
        <translation>Normalno</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <source>Mixed</source>
        <translation>Mešano</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location filename="../FileTreeModel.cc" line="+195"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Progress</source>
        <translation>Napredek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Download</source>
        <translation>Prenos</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Priority</source>
        <translation>Prioriteta</translation>
    </message>
</context>
<context>
    <name>FileTreeView</name>
    <message>
        <location filename="../FileTreeView.cc" line="+244"/>
        <source>Check Selected</source>
        <translation>Označi izbrane</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uncheck Selected</source>
        <translation>Odznači izbrane</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Only Check Selected</source>
        <translation>Označi le izbrane</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Priority</source>
        <translation>Prioriteta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rename…</source>
        <translation>Preimenuj …</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../FilterBar.cc" line="+48"/>
        <location line="+145"/>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <location line="-136"/>
        <source>Active</source>
        <translation>Aktivno</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading</source>
        <translation>Prenašanje</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding</source>
        <translation>Pošiljanje</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>V premoru</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Finished</source>
        <translation>Dokončano</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Verifying</source>
        <translation>V potrjevanju</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location line="+140"/>
        <source>Show:</source>
        <translation>Pokaži:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Search…</source>
        <translation>Išči …</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../Formatter.cc" line="+24"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>kB/s</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB/s</source>
        <translation>TB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+25"/>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <location line="-20"/>
        <location line="+10"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <location filename="../Formatter.h" line="+64"/>
        <location line="+7"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message numerus="yes">
        <location filename="../Formatter.cc" line="+41"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%Ln dan</numerusform>
            <numerusform>%Ln dneva</numerusform>
            <numerusform>%Ln dnevi</numerusform>
            <numerusform>%Ln dni</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-5"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln ura</numerusform>
            <numerusform>%Ln uri</numerusform>
            <numerusform>%Ln ure</numerusform>
            <numerusform>%Ln ur</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuta</numerusform>
            <numerusform>%Ln minuti</numerusform>
            <numerusform>%Ln minute</numerusform>
            <numerusform>%Ln minut</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%Ln sekunda</numerusform>
            <numerusform>%Ln sekundi</numerusform>
            <numerusform>%Ln sekunde</numerusform>
            <numerusform>%Ln sekund</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FreeSpaceLabel</name>
    <message>
        <location filename="../FreeSpaceLabel.cc" line="+52"/>
        <source>&lt;i&gt;Calculating Free Space…&lt;/i&gt;</source>
        <translation>&lt;i&gt;Računanje prostega prostora …&lt;/i&gt;</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>%1 free</source>
        <translation>%1 prosto</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../LicenseDialog.ui" line="+14"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+181"/>
        <source>&amp;Torrent</source>
        <translation>Torrent</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Create a new torrent</source>
        <translation>Ustvari nov torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Properties</source>
        <translation>Lastnosti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Pokaži lastnosti torrenta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Odpri mapo torrenta</translation>
    </message>
    <message>
        <location line="-161"/>
        <source>Queue</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <location line="-132"/>
        <source>Options</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <location line="+171"/>
        <source>&amp;Open…</source>
        <translation>&amp;Odpri …</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>Odpri torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;New…</source>
        <translation>&amp;Nov …</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Open Fold&amp;er</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Začni torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>Zahtevaj več soležnikov od sledilnika</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Zahtevaj več soležnikov od sledilnika</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Pavziraj torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Verify Local Data</source>
        <translation>Preveri krajevne podatke</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Preveri krajevne podatke</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Odstrani torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>Odstrani datoteke in torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Odstrani torrent in vse povezane datoteke</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Start All</source>
        <translation>Začni vse</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>Pavziraj vse</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>Izhod</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Select All</source>
        <translation>Izberi vse</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Deselect All</source>
        <translation>Izprazni izbor</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Preferences</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Compact View</source>
        <translation>Kompaktni pogled</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Kompaktni pogled</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Toolbar</source>
        <translation>Orodna vrstica</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>Vrstica filtra</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>Vrstica stanja</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Uredi po a&amp;ktivnosti</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Uredi po s&amp;tarosti</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Uredi po preostalem času</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Uredi po imenu</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Uredi po napredku</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Uredi po razmerju</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Uredi po velikosti</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Uredi po stanju</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Uredi po sledilniku</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>Dnevnik poročil</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>Vsebina</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;About</source>
        <translation>Več o</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>Obrni vrstni red urejanja</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>Datoteke</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>Sledilnik</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Skupno razmerje</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Sejno razmerje</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Skupni prenos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Sejni prenos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>Glavno okno</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>Ikona v opravilni vrstici</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session…</source>
        <translation>Spremeni sejo …</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set &amp;Location…</source>
        <translation>Nastavi mesto …</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;URL…</source>
        <translation>Odpri &amp;URL …</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Izberi sejo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>Kopiraj povezavo Magnet na odložišče</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Donate</source>
        <translation>Prispevaj</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>Začni zdaj</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>Preskoči vrsto in začni zdaj</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Move to &amp;Top</source>
        <translation>Premakni na vrh</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>Premakni navzgor</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move &amp;Down</source>
        <translation>Premakno navzdol</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Bottom</source>
        <translation>Premakni na dno</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>Uredi po vrsti</translation>
    </message>
    <message>
        <location filename="../MainWindow.cc" line="+468"/>
        <source>Limit Download Speed</source>
        <translation>Omeji hitrost prenašanja</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Unlimited</source>
        <translation>Neomejeno</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+752"/>
        <location line="+9"/>
        <source>Limited at %1</source>
        <translation>Omejena na %1</translation>
    </message>
    <message>
        <location line="-706"/>
        <source>Limit Upload Speed</source>
        <translation>Omeji hitrost pošiljanja</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Prenehaj sejati pri razmerju</translation>
    </message>
    <message>
        <location line="-40"/>
        <source>Seed Forever</source>
        <translation>Sej neomejeno</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+739"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Prenehaj pri razmerju (%1)</translation>
    </message>
    <message>
        <location line="-393"/>
        <source> - %1:%2</source>
        <extracomment>Second (optional) part of main window title &quot;Transmission - host:port&quot; (added when connected to remote session) notice that leading space (before the dash) is included here</extracomment>
        <translation> - %1:%2</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Idle</source>
        <translation>Neaktivno</translation>
    </message>
    <message>
        <location line="+30"/>
        <location line="+15"/>
        <source>Ratio: %1</source>
        <translation>Razmerje: %1</translation>
    </message>
    <message>
        <location line="-10"/>
        <location line="+5"/>
        <source>Down: %1, Up: %2</source>
        <translation>Dol: %1, Gor: %2</translation>
    </message>
    <message>
        <location line="+424"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Datoteke torrent (*.torrent);;Vse datoteke (*.*)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;options dialog</source>
        <translation>Pokaži okno za nastavitve</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Open Torrent</source>
        <translation>Odpri torrent</translation>
    </message>
    <message>
        <location line="-1003"/>
        <source>Speed Limits</source>
        <translation>Omejitve hitrosti</translation>
    </message>
    <message>
        <location line="+537"/>
        <source>Network Error</source>
        <translation>Napaka omrežja</translation>
    </message>
    <message>
        <location line="+434"/>
        <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Kliknite, da onemogočite začasne omejitve hitrosti
 (%1 dol, %2 gor)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Kliknite, da omogočite začasne omejitve hitrosti (%1 dol, %2 gor)</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Remove torrent?</source>
        <translation>Odstrani torrent?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>Izbriši prejete datoteke za ta torrent?</translation>
    </message>
    <message numerus="yes">
        <location line="-4"/>
        <source>Remove %Ln torrent(s)?</source>
        <translation>
            <numerusform>Odstrani %Ln torrent?</numerusform>
            <numerusform>Odstrani %Ln torrenta?</numerusform>
            <numerusform>Odstrani %Ln torrente?</numerusform>
            <numerusform>Odstrani %Ln torrentov?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-505"/>
        <source>Showing %L1 of %Ln torrent(s)</source>
        <translation>
            <numerusform>Prikazujem %L1 od %Ln torrent</numerusform>
            <numerusform>Prikazujem %L1 od %Ln torrenta</numerusform>
            <numerusform>Prikazujem %L1 od %Ln torrente</numerusform>
            <numerusform>Prikazujem %L1 od %Ln torrentov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+510"/>
        <source>Delete these %Ln torrent(s)&apos; downloaded files?</source>
        <translation>
            <numerusform>Izbriši datoteke od %Ln torrenta?</numerusform>
            <numerusform>Izbriši datoteke od %Ln torrentov?</numerusform>
            <numerusform>Izbriši datoteke od %Ln torrentov?</numerusform>
            <numerusform>Izbriši datoteke od %Ln torrentov?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Po odstrajevanju bo za nadaljevanje prenosa potrebno podati datoteko torrent ali povezavo magnet.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Po odstrajevanju bo za nadaljevanje prenosa potrebno podati datoteko torrent ali povezavo magnet.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent has not finished downloading.</source>
        <translation>Ta torrent še ni zaključil s prenosom.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>Ti torrenti še niso zaključili s prenosom.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent is connected to peers.</source>
        <translation>Ta torrent je povezan s soležniki.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>These torrents are connected to peers.</source>
        <translation>Ti torrenti so povezani s soležniki.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Eden od teh torrentov je povezan s soležniki.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Nekateri od teh torrentov so povezani s soležniki.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Eden od teh torrentov še ni zaključil s prenosom.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Nekateri od teh torrentov še niso zaključili s prenosom.</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>%1 has not responded yet</source>
        <translation>%1 se še ni odzval</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is responding</source>
        <translation>%1 se odziva</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 last responded %2 ago</source>
        <translation>%1 se je nazadnje odzval pred %2</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is not responding</source>
        <translation>%1 se ne odziva</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../MakeDialog.ui" line="+17"/>
        <source>New Torrent</source>
        <translation>Nov torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="+304"/>
        <source>&lt;i&gt;No source selected&lt;/i&gt;</source>
        <translation>&lt;i&gt;Ni izbranega vira&lt;/i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln datoteka</numerusform>
            <numerusform>%Ln datoteki</numerusform>
            <numerusform>%Ln datoteke</numerusform>
            <numerusform>%Ln datotek</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln kos</numerusform>
            <numerusform>%Ln kosa</numerusform>
            <numerusform>%Ln kosi</numerusform>
            <numerusform>%Ln kosov</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 v %2; %3 @ %4</translation>
    </message>
    <message>
        <location filename="../MakeDialog.ui" line="+9"/>
        <source>Files</source>
        <translation>Datoteke</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Sa&amp;ve to:</source>
        <translation>Shrani v:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Source f&amp;older:</source>
        <translation>Izvorna mapa:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Source &amp;file:</source>
        <translation>Izvorna datoteka:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Piece s&amp;ize:</source>
        <translation>Velikost kosov:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Properties</source>
        <translation>Lastnosti</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Trackers:</source>
        <translation>Sledilniki:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Za dodajanje pomožnega URL, ga dodajte na vrstico za glavnim URL.
Za dodajanje nadaljnjega glavnega URL, ga dodajte za prazno vrstico.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Co&amp;mment:</source>
        <translation>Komentar:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Source:</source>
        <translation>Vir:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Private torrent</source>
        <translation>Zasebni torrent</translation>
    </message>
</context>
<context>
    <name>MakeProgressDialog</name>
    <message>
        <location filename="../MakeProgressDialog.ui" line="+14"/>
        <source>New Torrent</source>
        <translation>Novi torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="-184"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>Ustvarjam &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>Ustvaril &quot;%1&quot;!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Couldn&apos;t create &quot;%1&quot;: %2 (%3)</source>
        <translation>Ni mogoče ustvariti &quot;%1&quot;: %2 (%3)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../OptionsDialog.cc" line="+52"/>
        <source>Open Torrent</source>
        <translation>Odpri torrent</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Open Torrent from File</source>
        <translation>Odpri torrent iz datoteke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open Torrent from URL or Magnet Link</source>
        <translation>Odpri torrent iz URL ali povezave Magnet</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+17"/>
        <source>&amp;Source:</source>
        <translation>Vir:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Destination folder:</source>
        <translation>Ciljna mapa:</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="+49"/>
        <source>High</source>
        <translation>Visoka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normalna</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Nizka</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+35"/>
        <source>&amp;Priority:</source>
        <translation>Prioriteta</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>S&amp;tart when added</source>
        <translation>Začni po dodajanju</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>Premakni datoteko .torrent v smeti</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="-40"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Datoteke torrent (*.torrent);;Vse datoteke (*.*)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Select Destination</source>
        <translation>Izberi cilj</translation>
    </message>
</context>
<context>
    <name>PathButton</name>
    <message>
        <location filename="../PathButton.cc" line="+23"/>
        <location line="+71"/>
        <source>(None)</source>
        <translation>(Brez)</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Select Folder</source>
        <translation>Izberi mapo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Select File</source>
        <translation>Izberi datoteko</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../PrefsDialog.ui" line="+1223"/>
        <source>Use &amp;authentication</source>
        <translation>Uporabi overjanje</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Username:</source>
        <translation>Uporabniško ime:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>Geslo:</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>&amp;Open web client</source>
        <translation>Odpri spletni vmesnik</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Addresses:</source>
        <translation>Naslovi:</translation>
    </message>
    <message>
        <location line="-1234"/>
        <source>Speed Limits</source>
        <translation>Omejitve hitrosti</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Zanemari navadne omejitve hitrosti ročno ali ob predpisanem času&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>&amp;Scheduled times:</source>
        <translation>Predpisani časi:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>&amp;On days:</source>
        <translation>Ob dnevih:</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+382"/>
        <source>Every Day</source>
        <translation>Vsak dan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Med tednom</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Med vikendom</translation>
    </message>
    <message>
        <location line="-238"/>
        <source>Sunday</source>
        <translation>Nedelja</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Monday</source>
        <translation>Ponedeljek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tuesday</source>
        <translation>Torek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Wednesday</source>
        <translation>Sreda</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Thursday</source>
        <translation>Četrtek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Friday</source>
        <translation>Petek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <location line="+299"/>
        <source>Port is &lt;b&gt;open&lt;/b&gt;</source>
        <translation>Vrata so &lt;b&gt;odprta&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Port is &lt;b&gt;closed&lt;/b&gt;</source>
        <translation>Vrata so &lt;b&gt;zaprta&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Testing TCP Port…</source>
        <translation>Preizkušam vrata TCP …</translation>
    </message>
    <message>
        <location line="+154"/>
        <source>Select &quot;Torrent Done Downloading&quot; Script</source>
        <translation>Izberi skripto za zaključek prenosa torrenta</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="+545"/>
        <source>Incoming Peers</source>
        <translation>Dohodni soležniki</translation>
    </message>
    <message>
        <location line="+32"/>
        <location filename="../PrefsDialog.cc" line="+207"/>
        <source>Status unknown</source>
        <translation>Neznan status</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>Vrata za dohodne povezave:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>Uporabi UPnP ali NAT-PMP posredovanje vrat na mojem usmerjevalniku</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="-255"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>minuta</numerusform>
            <numerusform>minuti</numerusform>
            <numerusform>minute</numerusform>
            <numerusform>minut</numerusform>
        </translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Select &quot;Torrent Done Seeding&quot; Script</source>
        <translation>Izberi skripto za zaključek sejanja torrenta</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source> minute(s) ago</source>
        <extracomment>Spin box suffix, &quot;Download is inactive if data sharing stopped: [ 5 minutes ago ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>minuto nazaj</numerusform>
            <numerusform>minutama nazaj</numerusform>
            <numerusform>minutami nazaj</numerusform>
            <numerusform>minutami nazaj</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-651"/>
        <source>Automatically add .torrent files &amp;from:</source>
        <translation>Samodejno dodaj .torrent datoteke iz:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Show the Torrent Options &amp;dialog</source>
        <translation>Pokaži okno možnosti torrenta</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>&amp;Start added torrents</source>
        <translation>Začni dodane torrente</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Mo&amp;ve the .torrent file to the trash</source>
        <translation>Premakni .torrent datoteko v smeti</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Download Queue</source>
        <translation>Vrsta prenosa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Ma&amp;ximum active downloads:</source>
        <translation>Največ aktivnih prenosov:</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Incomplete</source>
        <translation>Nedokončano</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Seeding</source>
        <translation>Sejanje</translation>
    </message>
    <message>
        <location line="+622"/>
        <source>Remote</source>
        <translation>Oddaljno</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="+168"/>
        <source>&lt;i&gt;Blocklist contains %Ln rule(s)&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;Seznam blokad vsebuje %Ln pravilo&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Seznam blokad vsebuje %Ln pravili&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Seznam blokad vsebuje %Ln pravila&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Seznam blokad vsebuje %Ln pravil&lt;/i&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-339"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>Izberi naključna vrata ob vsakem zagonu</translation>
    </message>
    <message>
        <location line="-274"/>
        <source>Limits</source>
        <translation>Omejitve</translation>
    </message>
    <message>
        <location line="+321"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Največ soležnikov na torrent:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>Največ soležnikov v celoti:</translation>
    </message>
    <message>
        <location line="-193"/>
        <source>Blocklist</source>
        <translation>Seznam blokad</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Enable &amp;automatic updates</source>
        <translation>Omogoči samodejne posodobitve</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-227"/>
        <source>Allow encryption</source>
        <translation>Dovoli šifriranje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Prednostno šifriraj</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Zahtevaj šifriranje</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-97"/>
        <source>Privacy</source>
        <translation>Zasebnost</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>&amp;to</source>
        <translation>do</translation>
    </message>
    <message>
        <location line="+847"/>
        <location line="+9"/>
        <source>Desktop</source>
        <translation>Namizje</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Pokaži ikono Transmission v območju za obvestila</translation>
    </message>
    <message>
        <location line="-265"/>
        <source>Te&amp;st Port</source>
        <translation>Preveri vrata</translation>
    </message>
    <message>
        <location line="-101"/>
        <source>Enable &amp;blocklist:</source>
        <translation>Omogoči seznam blokad</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Update</source>
        <translation>Posodobi</translation>
    </message>
    <message>
        <location line="-66"/>
        <source>&amp;Encryption mode:</source>
        <translation>Način šifriranja:</translation>
    </message>
    <message>
        <location line="+505"/>
        <source>Remote Control</source>
        <translation>Oddaljeni nadzor</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Allow &amp;remote access</source>
        <translation>Dovoli oddaljeni dostop</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>HTTP &amp;port:</source>
        <translation>Vrata HTTP:</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Only allow these IP a&amp;ddresses:</source>
        <translation>Dovoli le sledeče IP naslove:</translation>
    </message>
    <message>
        <location line="-1212"/>
        <source>&amp;Upload:</source>
        <translation>Poslano:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Download:</source>
        <translation>Prejeto;</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Alternative Speed Limits</source>
        <translation>Alternativne omejitve hitrosti</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>U&amp;pload:</source>
        <translation>Poslano:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Do&amp;wnload:</source>
        <translation>Prejeto:</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Reads user clipboard content for torrents</source>
        <translation>Beri vsebino odložišča za nove torrente</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Detect new torrents from clipboard</source>
        <translation>Zaznaj nove torrente z odložišča</translation>
    </message>
    <message>
        <location line="+148"/>
        <source>Call scrip&amp;t when downloading is completed:</source>
        <translation>Izvedi skripto ob dokončanju prenosa:</translation>
    </message>
    <message>
        <location line="+105"/>
        <source>Call scrip&amp;t when seeding is completed:</source>
        <translation>Izvedi skripto ob dokončanju sejanja:</translation>
    </message>
    <message>
        <location line="+342"/>
        <source>µTP is a tool for reducing network congestion.</source>
        <translation>µTP je orodje za zmanjševanje zasičenosti omrežja.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable µ&amp;TP for peer connections</source>
        <translation>Omogoči µTP za povezave s soležniki</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Default Public Trackers</source>
        <translation>Privzeti javni sledilniki</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trackers to use on all public torrents.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;p&gt;To add a new primary URL, add it after a blank line.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Sledilniki za uporabo na vseh javnih torrentih.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;Rezervni URL dodaj v vrstico za primarnim URL-jem.&lt;/p&gt;&lt;p&gt;Nov primarni URL dodaj po prazni vrstici.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Start &amp;minimized in notification area</source>
        <translation>Začni minimirano v območju za obvestila</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Notification</source>
        <translation>Obvestila</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show a notification when torrents are a&amp;dded</source>
        <translation>Pokaži obvestilo ob dodajanju torrentov</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show a notification when torrents &amp;finish</source>
        <translation>Pokaži obvestilo ob zaključku torrentov</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Play a &amp;sound when torrents finish</source>
        <translation>Predvajaj zvok ob zaključku torrentov</translation>
    </message>
    <message>
        <location line="-281"/>
        <source>Peer Limits</source>
        <translation>Omejitve soležnikov</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>Uporabi PEX za iskanje več soležnikov</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>PEX je orodje za izmenjavo seznamov soležnikov z že povezanimi soležniki.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>Uporabi DHT za iskanje več soležnikov</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>DHT je orodje za iskanje soležnikov brez sledilnika.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>Uporabi LPD za iskanje več soležnikov</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>LPD je orodje za iskanje več virov na krajevnem omrežju.</translation>
    </message>
    <message>
        <location line="-325"/>
        <source>Encryption</source>
        <translation>Šifriranje</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+75"/>
        <source>Select Incomplete Directory</source>
        <translation>Izberi mapo za nedokončano</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Select Watch Directory</source>
        <translation>Izberi mapo za opazovanje</translation>
    </message>
    <message numerus="yes">
        <location line="-101"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rule(s).&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;b&gt;Posodobitev uspešna!&lt;/b&gt;&lt;p&gt;Seznam blokad ima sedaj eno pravilo. &lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Posodobitev uspešna!&lt;/b&gt;&lt;p&gt;Seznam blokad ima sedaj %Ln pravili. &lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Posodobitev uspešna!&lt;/b&gt;&lt;p&gt;Seznam blokad ima sedaj %Ln pravil.&lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Posodobitev uspešna!&lt;/b&gt;&lt;p&gt;Seznam blokad ima sedaj %Ln pravil.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist…&lt;/p&gt;</source>
        <translation>&lt;b&gt;Posodobi seznam blokad&lt;/b&gt;&lt;p&gt;Pridobivanje novega seznama blokad...</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Select Destination</source>
        <translation>Izberi cilj</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-387"/>
        <source>Adding</source>
        <translation>Dodajanje</translation>
    </message>
    <message>
        <location line="+147"/>
        <source>Download is i&amp;nactive if data sharing stopped:</source>
        <extracomment>Please keep this phrase as short as possible, it&apos;s currently the longest and influences dialog width</extracomment>
        <translation>Prejem je neaktiven, če se je deljenje podatkov nehalo:</translation>
    </message>
    <message>
        <location line="-156"/>
        <source>Downloading</source>
        <translation>Prejemanje</translation>
    </message>
    <message>
        <location line="+215"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>Dodaj &quot;.part&quot; k imenom nedokončanih datotek</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>Hrani nedokončane datoteke:</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Save to &amp;Location:</source>
        <translation>Shrani na mesto:</translation>
    </message>
    <message>
        <location line="+282"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>Prenehaj sejati pri razmerju:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Stop seedi&amp;ng if idle for:</source>
        <translation>Prenehaj sejati pri neaktivnosti:</translation>
    </message>
    <message>
        <location line="-567"/>
        <source>Transmission Preferences</source>
        <translation>Nastavitve Transmission</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Speed</source>
        <translation>Hitrost</translation>
    </message>
    <message>
        <location line="+735"/>
        <source>Network</source>
        <translation>Omrežje</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+116"/>
        <source>Not supported by remote sessions</source>
        <translation>Ni podprto preko oddaljenih sej</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../Application.cc" line="-313"/>
        <source>Invalid option</source>
        <translation>Neveljavna možnost</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Start Now</source>
        <translation>Začni zdaj</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../RelocateDialog.cc" line="+65"/>
        <source>Select Location</source>
        <translation>Izberi mesto</translation>
    </message>
    <message>
        <location filename="../RelocateDialog.ui" line="+14"/>
        <source>Set Torrent Location</source>
        <translation>Nastavi mesto torrenta</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Set Location</source>
        <translation>Nastavi mesto</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>New &amp;location:</source>
        <translation>Novo mesto:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Move from the current folder</source>
        <translation>Premakni iz trenutne mape</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Local data is &amp;already there</source>
        <translation>Krajevni podatki so že na mestu</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../Session.cc" line="+505"/>
        <source>Error Renaming Path</source>
        <translation>Napaka pri preimenovanju poti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;p&gt;&lt;b&gt;Unable to rename &quot;%1&quot; as &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please correct the errors and try again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Ni možno preimenovati &quot;%1&quot; v &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Prosimo, popravite napake in poskusite znova.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+528"/>
        <source>Error Adding Torrent</source>
        <translation>Napaka pri dodajanju torrenta</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>%1 (copy of %2)</source>
        <translation>%1 (kopija %2)</translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>Duplicate Torrent(s)</source>
        <translation>
            <numerusform>Podvojeni torrent</numerusform>
            <numerusform>Podvojena torrenta</numerusform>
            <numerusform>Podvojeni torrenti</numerusform>
            <numerusform>Podvojeni torrenti</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>Unable to add %n duplicate torrent(s)</source>
        <translation>
            <numerusform>Ni mogoče dodati podvojenega torrenta</numerusform>
            <numerusform>Ni mogoče dodati %n podvojenih torrentov</numerusform>
            <numerusform>Ni mogoče dodati %n podvojenih torrentov</numerusform>
            <numerusform>Ni mogoče dodati %n podvojenih torrentov</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../SessionDialog.ui" line="+14"/>
        <source>Change Session</source>
        <translation>Spremeni sejo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Source</source>
        <translation>Vir</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Start &amp;Local Session</source>
        <translation>Začni krajevno sejo</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>Poveži se v oddaljeno sejo</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Host:</source>
        <translation>Gostitelj:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Port:</source>
        <translation>Vrata:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Authentication required</source>
        <translation>Zahtevano overjanje</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>Uporabniško ime:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>Geslo:</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../StatsDialog.ui" line="+14"/>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Current Session</source>
        <translation>Trenutna seja</translation>
    </message>
    <message>
        <location line="+12"/>
        <location line="+96"/>
        <source>Uploaded:</source>
        <translation>Poslano:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Downloaded:</source>
        <translation>Prejeto:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Ratio:</source>
        <translation>Razmerje:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Duration:</source>
        <translation>Trajanje:</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Total</source>
        <translation>Skupno</translation>
    </message>
    <message numerus="yes">
        <location filename="../StatsDialog.cc" line="+63"/>
        <source>Started %Ln time(s)</source>
        <translation>
            <numerusform>Začeto %Ln-krat</numerusform>
            <numerusform>Začeto %Ln-krat</numerusform>
            <numerusform>Začeto %Ln-krat</numerusform>
            <numerusform>Začeto %Ln-krat</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../Torrent.cc" line="+323"/>
        <source>Verifying local data</source>
        <translation>Preverjam krajevne podatke</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Downloading</source>
        <translation>Prejemanje</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seeding</source>
        <translation>Sejanje</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Finished</source>
        <translation>Končano</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>V premoru</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Queued for verification</source>
        <translation>V vrsti za preverjanje</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for download</source>
        <translation>V vrsti za prejemanje</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for seeding</source>
        <translation>V vrsti za pošiljanje</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Tracker gave a warning: %1</source>
        <translation>Sledilnik je vrnil opozorilo: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tracker gave an error: %1</source>
        <translation>Sledilnik je vrnil napako: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Error: %1</source>
        <translation>Napaka: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../TorrentDelegate.cc" line="+174"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <extracomment>First part of torrent progress string, %1 is the percentage of torrent metadata downloaded</extracomment>
        <translation>Magnetiziran prenos - pridobivam metapodatke (%1)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is how much we&apos;ll have when done, %3 is a percentage of the two</extracomment>
        <translation>%1 od %2 (%3%)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio, %6 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1 od %2 (%3%), poslano %4 (Razmerje: %5 Konec: %6)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio</extracomment>
        <translation>%1 od %2 (%3%), poslano %4 (Razmerje: %5)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio, %4 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1, poslano %2 (Razmerje: %3 Konec: %4)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio</extracomment>
        <translation>%1, poslano %2 (Razmerje: %3)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source> - %1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation>- %1 preostalo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source> - Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation> - Remaining time unknown</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Ratio: %1</source>
        <translation>Razmerje: %1</translation>
    </message>
    <message numerus="yes">
        <location line="+44"/>
        <source>Downloading from %Ln peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Prenašam od %Ln soležnika</numerusform>
            <numerusform>Prenašam od %Ln soležnikov</numerusform>
            <numerusform>Prenašam od %Ln soležnikov</numerusform>
            <numerusform>Prenašam od %Ln soležnikov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+22"/>
        <source>Seeding to %Ln peer(s)</source>
        <translation>
            <numerusform>Pošiljam %Ln soležniku</numerusform>
            <numerusform>Pošiljam %Ln soležnikoma</numerusform>
            <numerusform>Pošiljam %Ln soležnikom</numerusform>
            <numerusform>Pošiljam %Ln soležnikom</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message numerus="yes">
        <location line="-50"/>
        <source>Downloading metadata from %Ln peer(s) (%1% done)</source>
        <translation>
            <numerusform>Prenašam metapodatke od %Ln soležnika (%1% dokončano)</numerusform>
            <numerusform>Prenašam metapodatke od %Ln soležnikov (%1% dokončano)</numerusform>
            <numerusform>Prenašam metapodatke od %Ln soležnikov (%1% dokončano)</numerusform>
            <numerusform>Prenašam metapodatke od %Ln soležnikov (%1% dokončano)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+15"/>
        <source>Downloading from %1 of %Ln connected peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Prenašam od %1 od %Ln povezanega soležnika</numerusform>
            <numerusform>Prenašam od %1 od %Ln povezanih soležnikov</numerusform>
            <numerusform>Prenašam od %1 od %Ln povezanih soležnikov</numerusform>
            <numerusform>Prenašam od %1 od %Ln povezanih soležnikov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+8"/>
        <source> and %Ln web seed(s)</source>
        <extracomment>Second (optional) part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;, notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform>in %Ln spletnega semena</numerusform>
            <numerusform>in %Ln spletnih semen</numerusform>
            <numerusform>in %Ln spletnih semen</numerusform>
            <numerusform>in %Ln spletnih semen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+13"/>
        <source>Seeding to %1 of %Ln connected peer(s)</source>
        <translation>
            <numerusform>Sejem %1 od %Ln povezanega soležnika</numerusform>
            <numerusform>Sejem %1 od %Ln povezanih soležnikov</numerusform>
            <numerusform>Sejem %1 od %Ln povezanih soležnikov</numerusform>
            <numerusform>Sejem %1 od %Ln povezanih soležnikov</numerusform>
        </translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Preverjam krajevne podatke (%1% preverjeno)</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message numerus="yes">
        <location filename="../TrackerDelegate.cc" line="+216"/>
        <source>Got a list of%1 %Ln peer(s)%2 %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>
            <numerusform>Dobil seznam%1 %Ln vira pred%2 %3</numerusform>
            <numerusform>Dobil seznam%1 %Ln virov pred%2 %3</numerusform>
            <numerusform>Dobil seznam%1 %Ln virov pred%2 %3</numerusform>
            <numerusform>Dobil seznam%1 %Ln virov pred%2 %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Zahtevek za seznam soležnikov %1se je iztekel pred2 %3; bom kasneje poskusil znova</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Zanana napaka %1&quot;%2&quot;%3 pred %4</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>Ni načrtovanih posodobitev</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Prosim za več soležnikov čez %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for more peers</source>
        <translation>Načrtovana prošnja za več soležnikov</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Asking for peer counts now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Povpraševanje po številu soležnikov … &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="-40"/>
        <source>Tracker had%1 %Ln seeder(s)%2</source>
        <extracomment>First part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup</extracomment>
        <translation>
            <numerusform>Sledilnik je imel%1 %Ln sejalca%2</numerusform>
            <numerusform>Sledilnik je imel%1 %Ln sejalcev%2</numerusform>
            <numerusform>Sledilnik je imel%1 %Ln sejalcev%2</numerusform>
            <numerusform>Sledilnik je imel%1 %Ln sejalcev%2</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source> and%1 %Ln leecher(s)%2 %3 ago</source>
        <extracomment>Second part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup, %3 is duration; notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> in%1 %Ln odjemalca pred%2 %3</numerusform>
            <numerusform> in%1 %Ln odjemalcev pred%2 %3</numerusform>
            <numerusform> in%1 %Ln odjemalce pred%2 %3</numerusform>
            <numerusform> in%1 %Ln odjemalcev pred%2 %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tracker had %1no information%2 on peer counts %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Sledilnik %1ni imel informacij%2 o številu soležnikov pred %3</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Napaka pri pridobivanju %1&quot;%2&quot;%3 pred %4</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Asking for more peers now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Zahtevanje več soležnikov … &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Asking for peer counts in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Prosim za število soležnikov čez %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for peer counts</source>
        <translation>Načrtovana prošnja za število soležnikov</translation>
    </message>
</context>
<context>
    <name>TrackersDialog</name>
    <message>
        <location filename="../TrackersDialog.ui" line="+17"/>
        <source>Edit Trackers</source>
        <translation>Uredi sledilnike</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Tracker Announce URLs</source>
        <translation>URL-ji za objave sledilnika</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>To add a new primary URL, add it after a blank line.</source>
        <translation>Nov primarni URL dodaj po prazni vrstici.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Rezervni URL dodaj v vrstico za primarni URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Also see Default Public Trackers in Edit &gt; Preferences &gt; Network</source>
        <translation>Glej tudi Privzete javne sledilnike v Uredi &gt; Nastavitve &gt; Omrežje</translation>
    </message>
</context>
</TS>
